========
Aeromiko
========

Aeromiko is a middle-man script to simplify extracting data from Aerohive APs using Netmiko

Installation
------------

To install Aeromiko, simply use pip:

  $ pip install Aeromiko

Aeromiko has the following requirements (which pip will install for you)

- netmiko >= 2.4.0

Example Script:
~~~~~~~~~~~~~~~

`https://github.com/andytruett/Aeromiko/tree/master/example <https://github.com/andytruett/Aeromiko/tree/master/example>`_

.. image:: https://raw.githubusercontent.com/andytruett/Aeromiko/master/example/example.png
